Rdocumentation
powered by
Learn R Programming
bigSurvSGD (version 0.0.1)
oneChunkC: Updates the coefficients based on one pass of data
Description
Updates the coefficients based on one pass of data
Arguments